
use strict;
use warnings;

package PodPrivate;
our $VERSION = '0.092400';


=head1 NAME

PodPrivate - there are privacy instructions in POD

=begin Pod::Coverage

  not_covered

p...s

=end Pod::Coverage

=cut

sub not_covered { }

sub pants { }

1;
