
use strict;
use warnings;

package PodFor;
our $VERSION = '0.092400';


=head1 NAME

PodFor - there are privacy instructions in POD =for

=for Pod::Coverage not_covered p...s

=cut

sub not_covered { }

sub pants { }

1;
